.. _physics:

=============================
 Physics
=============================


The Python Package SymPy can be used to symbolically solve physics problems
on Classical Mechanics, Continuum Mechanics, Control Systems, High-Energy
Physics, Optics, Quantum Mechanics, Units and Vector algebra.

.. toctree::
   :maxdepth: 1

   control_problems.rst
